@@ -85,7 +85,11 @@ SearchStringInput::SearchStringInput( Kiten *parent )
   }
 
   //connect(actionTextInput, SIGNAL(returnPressed()), this, SIGNAL(search()));
+#if QT_VERSION < QT_VERSION_CHECK(5, 14, 0)
   connect(_actionTextInput, static_cast<void (KHistoryComboBox::*)(const QString &)>(&KHistoryComboBox::activated), this, &SearchStringInput::test);
+#else
+  connect(_actionTextInput, static_cast<void (KHistoryComboBox::*)(const QString &)>(&KHistoryComboBox::textActivated), this, &SearchStringInput::test);
+#endif
 }
 
 void SearchStringInput::focusInput()
@@ -130,10 +134,10 @@ void SearchStringInput::setSearchQuery( const DictQuery &query )
   DictQuery copy( query );
   foreach( KToolBar *bar, _parent->toolBars() )
   {
-    if( bar->widgetForAction( _actionFilterRare ) != NULL )
+    if( bar->widgetForAction( _actionFilterRare ) != nullptr )
       copy.removeProperty( QStringLiteral("common") );
 
-    if( bar->widgetForAction( _actionSelectWordType ) != NULL )
+    if( bar->widgetForAction( _actionSelectWordType ) != nullptr )
       copy.removeProperty(QStringLiteral("type"));
   }
 
