@@ -51,22 +51,22 @@ class RadSelect : public KXmlGuiWindow
 
   protected:
     // Overridden virtuals for Qt drag 'n drop (XDND)
-    void dragEnterEvent( QDragEnterEvent *event ) Q_DECL_OVERRIDE;
-    void dropEvent( QDropEvent *event ) Q_DECL_OVERRIDE;
+    void dragEnterEvent( QDragEnterEvent *event ) override;
+    void dropEvent( QDropEvent *event ) override;
 
   protected:
     /**
      * This function is called when it is time for the app to save its
      * properties for session management purposes.
      */
-    void saveProperties( KConfigGroup &config ) Q_DECL_OVERRIDE;
+    void saveProperties( KConfigGroup &config ) override;
 
     /**
      * This function is called when this app is restored. The KConfig
      * object points to the session management config file that was saved
      * with @ref saveProperties
      */
-    void readProperties( const KConfigGroup &config ) Q_DECL_OVERRIDE;
+    void readProperties( const KConfigGroup &config ) override;
 
 
   private slots:
